@@ -3,11 +3,9 @@
 
 import time
 import board
-import busio
 import adafruit_msa301
 
-i2c = busio.I2C(board.SCL, board.SDA)
-
+i2c = board.I2C()  # uses board.SCL and board.SDA
 msa = adafruit_msa301.MSA301(i2c)
 
 msa.enable_tap_detection()
